(self.webpackChunk_N_E=self.webpackChunk_N_E||[]).push([[177],{3497:(e,t,n)=>{Promise.resolve().then(n.t.bind(n,8493,23)),Promise.resolve().then(n.bind(n,33908))},8493:()=>{},33908:(e,t,n)=>{"use strict";n.d(t,{default:()=>N});var r=n(79367),s=n(77721),a=n(4434);function l(e,t){(0,a.oo)("#!"+e)}let o=e=>[(0,a.W9)(()=>window.location.hash.replace(/^#!/,"")||"/",()=>"/ssr"),l];var i=n(13903),c=n(82633),d=n(5007),m=n(93569),u=n(44957),h=n(97887),f=n(26901),y=n(43094),p=n(12877);function v(e){let{children:t}=e;return(0,r.jsx)(y.R,{children:(0,r.jsx)(p.p,{children:(0,r.jsx)(m.F7,{children:(0,r.jsx)(u.kL,{children:(0,r.jsx)(m.$U,{children:(0,r.jsx)(h.dZ,{children:(0,r.jsx)(f.d,{children:t})})})})})})})}var b=n(30724),g=(e,t,n,r,s,a,l,o)=>{let i=document.documentElement,c=["light","dark"];function d(t){var n;(Array.isArray(e)?e:[e]).forEach(e=>{let n="class"===e,r=n&&a?s.map(e=>a[e]||e):s;n?(i.classList.remove(...r),i.classList.add(a&&a[t]?a[t]:t)):i.setAttribute(e,t)}),n=t,o&&c.includes(n)&&(i.style.colorScheme=n)}if(r)d(r);else try{let e=localStorage.getItem(t)||n,r=l&&"system"===e?window.matchMedia("(prefers-color-scheme: dark)").matches?"dark":"light":e;d(r)}catch(e){}},w=["light","dark"],x="(prefers-color-scheme: dark)",k="undefined"==typeof window,E=d.createContext(void 0),S=e=>d.useContext(E)?d.createElement(d.Fragment,null,e.children):d.createElement(C,{...e}),j=["light","dark"],C=e=>{let{forcedTheme:t,disableTransitionOnChange:n=!1,enableSystem:r=!0,enableColorScheme:s=!0,storageKey:a="theme",themes:l=j,defaultTheme:o=r?"system":"light",attribute:i="data-theme",value:c,children:m,nonce:u,scriptProps:h}=e,[f,y]=d.useState(()=>L(a,o)),[p,v]=d.useState(()=>"system"===f?_():f),b=c?Object.values(c):l,g=d.useCallback(e=>{let t=e;if(!t)return;"system"===e&&r&&(t=_());let a=c?c[t]:t,l=n?A(u):null,d=document.documentElement,m=e=>{"class"===e?(d.classList.remove(...b),a&&d.classList.add(a)):e.startsWith("data-")&&(a?d.setAttribute(e,a):d.removeAttribute(e))};if(Array.isArray(i)?i.forEach(m):m(i),s){let e=w.includes(o)?o:null,n=w.includes(t)?t:e;d.style.colorScheme=n}null==l||l()},[u]),k=d.useCallback(e=>{let t="function"==typeof e?e(f):e;y(t);try{localStorage.setItem(a,t)}catch(e){}},[f]),S=d.useCallback(e=>{v(_(e)),"system"===f&&r&&!t&&g("system")},[f,t]);d.useEffect(()=>{let e=window.matchMedia(x);return e.addListener(S),S(e),()=>e.removeListener(S)},[S]),d.useEffect(()=>{let e=e=>{e.key===a&&(e.newValue?y(e.newValue):k(o))};return window.addEventListener("storage",e),()=>window.removeEventListener("storage",e)},[k]),d.useEffect(()=>{g(null!=t?t:f)},[t,f]);let C=d.useMemo(()=>({theme:f,setTheme:k,forcedTheme:t,resolvedTheme:"system"===f?p:f,themes:r?[...l,"system"]:l,systemTheme:r?p:void 0}),[f,k,t,p,r,l]);return d.createElement(E.Provider,{value:C},d.createElement(T,{forcedTheme:t,storageKey:a,attribute:i,enableSystem:r,enableColorScheme:s,defaultTheme:o,value:c,themes:l,nonce:u,scriptProps:h}),m)},T=d.memo(e=>{let{forcedTheme:t,storageKey:n,attribute:r,enableSystem:s,enableColorScheme:a,defaultTheme:l,value:o,themes:i,nonce:c,scriptProps:m}=e,u=JSON.stringify([r,n,l,t,i,o,s,a]).slice(1,-1);return d.createElement("script",{...m,suppressHydrationWarning:!0,nonce:"undefined"==typeof window?c:"",dangerouslySetInnerHTML:{__html:"(".concat(g.toString(),")(").concat(u,")")}})}),L=(e,t)=>{let n;if(!k){try{n=localStorage.getItem(e)||void 0}catch(e){}return n||t}},A=e=>{let t=document.createElement("style");return e&&t.setAttribute("nonce",e),t.appendChild(document.createTextNode("*,*::before,*::after{-webkit-transition:none!important;-moz-transition:none!important;-o-transition:none!important;-ms-transition:none!important;transition:none!important}")),document.head.appendChild(t),()=>{window.getComputedStyle(document.body),setTimeout(()=>{document.head.removeChild(t)},1)}},_=e=>(e||(e=window.matchMedia(x)),e.matches?"dark":"light");function O(e){return(0,r.jsx)(S,{attribute:"class",disableTransitionOnChange:!0,...e})}var P=n(77498);function I(e){return(0,r.jsx)(b.s,{value:P.q,children:(0,r.jsx)(O,{...e})})}var M=n(25035);function N(e){let{children:t}=e;return(0,r.jsx)(I,{forcedTheme:"light",children:(0,r.jsx)(i.Ht,{client:s.x,children:(0,r.jsx)(c.Ix,{hook:o,children:(0,r.jsxs)(v,{children:[t,(0,r.jsx)(M.l,{})]})})})})}}},e=>{var t=t=>e(e.s=t);e.O(0,[844,830,14,72,452,383,265,138,587,598,17,71,583,545,88,358],()=>t(3497)),_N_E=e.O()}]);